import argparse
import active_sessions

# Create an argument parser.
parser = argparse.ArgumentParser('active-sessions')


def main(args=None):
    """Main entry point for your project.
    """


if __name__ == '__main__':
    main(['-h'])



from django.contrib.auth.models import User
from django.contrib.sessions.models import Session
from django.core.signals import request_finished
from django.dispatch import receiver
from django.utils import timezone
import active_sessions

def get_current_users():
    active_sessions = Session.objects.filter(expire_date__gte=timezone.now())
    user_id_list = []
    for session in active_sessions:
        data = session.get_decoded()
        user_id_list.append(data.get('_auth_user_id', None))
    # Query all logged in users based on id list
    return User.objects.filter(id__in=user_id_list)


request_finished.connect(show_sessions)
@receiver(request_finished)
def show_sessions(sender, **kwargs):
    queryset = get_current_users()
    print("Active sessions: ", queryset.count())



# -*- coding: utf8 -*-
#
# This file were created by Python Boilerplate. Use boilerplate to start simple
# usable and best-practices compliant Python projects.
#
# Learn more about it at: http://github.com/fabiommendes/boilerplate/
#

import os
from setuptools import setup, find_packages


# Meta information
name = 'active-sessions'
project = 'active_sessions'
author = 'Tiago Assuncao'
version = open('VERSION').read().strip()
dirname = os.path.dirname(__file__)


# Save version and author to __meta__.py
with open(os.path.join(dirname, 'src', project, '__meta__.py'), 'w') as F:
    F.write('__version__ = %r\n__author__ = %r\n' % (version, author))


setup(
    # Basic info
    name=name,
    version=version,
    author=author,
    author_email='tiago@sof2u.com',
    url='',
    description='A short description for your project.',
    long_description=open('README.rst').read(),

    # Classifiers (see https://pypi.python.org/pypi?%3Aaction=list_classifiers)
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries',
    ],

    # Packages and depencies
    package_dir={'': 'src'},
    packages=find_packages('src'),
    install_requires=[],
    extras_require={
        'testing': ['pytest'],
    },

    # Scripts
    entry_points={
        'active_session': [
            'active_session = active_sessions.__main__:main'
            'active-sessions = active_sessions.__main__:get_current_users'
        ],
    },

    # Other configurations
    zip_safe=False,
    platforms='any',
    test_suite='%s.test.test_%s' % (name, name),
)
